@@ -2,12 +2,23 @@ from __future__ import annotations
 
 from typing import Any
 
+import sphinx.util
 from sphinx.application import Sphinx
 
 from .handlers import html_page_context_handler
 from .roles import EmailRole
 
-__version__ = "0.3.3"
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata
+
+try:
+    __version__ = ".".join(metadata.version("sphinxcontrib-email").split(".")[:3])
+except metadata.PackageNotFoundError:
+    pass
+
+logger = sphinx.util.logging.getLogger(__name__)
 
 
 def setup(app: Sphinx) -> dict[str, Any]:
