@@ -4,10 +4,13 @@ import html
 import urllib.parse
 
 import lxml.html  # nosec  # noqa DUO107
+import sphinx.util
 from sphinx.application import Sphinx
 
 from .utils import Obfuscator
 
+logger = sphinx.util.logging.getLogger(__name__)
+
 
 def html_page_context_handler(
     app: Sphinx, pagename: str, templatename: str, context: dict, doctree: bool
@@ -18,7 +21,7 @@ def html_page_context_handler(
     if not doctree:
         return
 
-    tree = lxml.html.fragment_fromstring(context["body"])
+    tree = lxml.html.fragment_fromstring(context["body"], create_parent="body")
     links = tree.iterlinks()
     links = filter(lambda link: link[2].startswith("mailto:"), list(links))
 
@@ -32,4 +35,9 @@ def html_page_context_handler(
         new_node.tail = tail_str
 
         old_node.getparent().replace(old_node, new_node)
-    context["body"] = lxml.html.tostring(tree, encoding="unicode")
+
+    child_strs = map(
+        lambda child: lxml.html.tostring(child, pretty_print=True, encoding="unicode"),
+        tree.iterchildren(),
+    )
+    context["body"] = "".join(child_strs)
